@@ -59,6 +59,13 @@ def get_iamge():
     screen_shot('android',None)
     crop()
 
-def element_click(element_keywords_name):
-    u2.connect_usb().xpath(element_keywords_name).click()
+def element_click(Prop,Value):
+    if Prop=='xpath' or Prop=='XPath':
+        u2.connect_usb().xpath(Value).click()
+    else:
+        a='u2.connect_usb()('
+        b='=Value).click()'
+        c=a+Prop+b
+        eval(c)
+
 
